# ifndef yyInterchange
# define yyInterchange

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* Interchange_Exit) ARGS ((void));

extern rbool CanBeInterchanged ARGS ((tTree loop1));

extern void BeginInterchange ARGS ((void));
extern void CloseInterchange ARGS ((void));

# endif
